/*
Copyright (C) 2006 Evan Teran
                   eteran@alum.rit.edu

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

#ifndef DEBUGEVENT_20060720_H_
#define DEBUGEVENT_20060720_H_

#include "Types.h"
#include "DebugEventBase.h"
#include <QString>
#include <QPair>
#include <signal.h>	// for the SIG* definitions
#include "API.h"

class EDB_EXPORT DebugEvent : public DebugEventBase {
public:
	int			status;
	int			code;
	edb::pid_t	pid;
	edb::tid_t	tid;
	
	DebugEvent();
	DebugEvent(int s, int c, edb::pid_t pid, edb::tid_t tid);
	DebugEvent(const DebugEvent &other);
	DebugEvent &operator=(const DebugEvent &rhs);

	int exitCode() const;
	int signalCode() const;
	int stopCode() const;
	REASON reason() const;
	edb::tid_t thread() const;
	edb::pid_t process() const;
	
	bool exited() const;
	bool signaled() const;
	bool stopped() const;
	
	// stops
	static const int sigstop	= SIGSTOP;
	static const int sigtrap	= SIGTRAP;

	static const int sigkill	= SIGKILL;
	static const int sigalrm	= SIGALRM;
	
	bool isError() const;
	Message errorDescription(edb::address_t fault_address);
};

#endif

